@@ -1,13 +1,12 @@
 import inspect
-
 from functools import wraps
-from typing import Any, Callable, cast, List, Optional, Tuple
+from typing import Any, Callable, List, Optional, Tuple, cast
 
 from rap.client.model import Response
-from rap.client.transport import Transport
+from rap.client.processor.base import BaseProcessor
+from rap.client.transoprt.channel import Channel
+from rap.client.transoprt.transport import Session, Transport
 from rap.common.conn import Connection
-from rap.common.middleware import BaseMiddleware
-
 
 __all__ = ["Client"]
 
@@ -18,11 +17,19 @@ class AsyncIteratorCall:
     def __init__(self, method: str, client: "Client", *args: Tuple):
         self._method: str = method
         self._call_id: Optional[int] = None
-        self._args = args
+        self._args: Tuple = args
         self._client: "Client" = client
         self._conn: Connection = self._client.transport.now_conn
+        self._session: Session = self._client.transport.session
 
-    def __aiter__(self):
+    async def __aenter__(self) -> "AsyncIteratorCall":
+        self._session.create()
+        return self
+
+    async def __aexit__(self, *args: Tuple):
+        self._session.close()
+
+    def __aiter__(self) -> "AsyncIteratorCall":
         return self
 
     async def __anext__(self):
@@ -51,10 +58,7 @@ class Client:
         if not host_list:
             host_list = ["localhost:9000"]
         self.transport: Transport = Transport(
-            host_list,
-            timeout=timeout,
-            keep_alive_time=keep_alive_time,
-            ssl_crt_path=ssl_crt_path
+            host_list, timeout=timeout, keep_alive_time=keep_alive_time, ssl_crt_path=ssl_crt_path
         )
 
     ##################
@@ -72,8 +76,8 @@ class Client:
         """
         await self.transport.connect()
 
-    def load_middleware(self, middleware_list: List[BaseMiddleware]):
-        self.transport.load_middleware(middleware_list)
+    def load_middleware(self, middleware_list: List[BaseProcessor]):
+        self.transport.load_processor(middleware_list)
 
     # register
     def _async_register(self, func: Callable):
@@ -87,6 +91,7 @@ class Client:
 
     def _async_gen_register(self, func: Callable):
         """Decoration generator function"""
+
         @wraps(func)
         async def wrapper(*args, **kwargs) -> Any:
             async for result in self.iterator_call(func.__name__, *args):
@@ -94,6 +99,16 @@ class Client:
 
         return cast(Callable, wrapper)
 
+    def _async_channel_register(self, func: Callable):
+        """Decoration generator function"""
+
+        @wraps(func)
+        async def wrapper(*args, **kwargs) -> Any:
+            async with self.transport.channel(func.__name__) as channel:
+                await func(channel)
+
+        return cast(Callable, wrapper)
+
     # client api
     async def raw_call(self, method: str, *args: Any) -> Any:
         """rpc client base call method"""
@@ -106,12 +121,18 @@ class Client:
 
     async def iterator_call(self, method: str, *args: Any) -> Any:
         """Python-specific generator call"""
-        async for result in AsyncIteratorCall(method, self, *args):
-            yield result
+        async with AsyncIteratorCall(method, self, *args) as async_iterator:
+            async for result in async_iterator:
+                yield result
 
     def register(self, func: Callable) -> Any:
         """Using this method to decorate a fake function can help you use it better.
         (such as ide completion, ide reconstruction and type hints)"""
+        func_sig: inspect.Signature = inspect.signature(func)
+        func_arg_parameter: List[inspect.Parameter] = [i for i in func_sig.parameters.values() if i.default == i.empty]
+        if len(func_arg_parameter) == 1 and func_arg_parameter[0].annotation is Channel:
+            return self._async_channel_register(func)
+
         if inspect.iscoroutinefunction(func):
             return self._async_register(func)
         elif inspect.isasyncgenfunction(func):
