@@ -3,19 +3,19 @@ import random
 import string
 import sys
 import time
-
 from dataclasses import dataclass
-from typing import Dict
+from typing import Any, Dict
 
 __all__ = [
-    "get_event_loop",
-    "response_num_dict",
     "Constant",
     "Event",
     "MISS_OBJECT",
+    "State",
     "gen_random_time_id",
     "gen_random_str_id",
+    "get_event_loop",
     "parse_error",
+    "response_num_dict",
 ]
 
 from typing import Optional, Tuple
@@ -43,6 +43,35 @@ class Constant(object):
     PING_EVENT: str = "ping"
     PONG_EVENT: str = "pong"
 
+    DECLARE: str = "declare"
+    MSG: str = "MSG"
+    DROP: str = "drop"
+
+    NORMAL: str = "normal"
+    CHANNEL: str = "channel"
+
+
+class State(object):
+    def __init__(self, state: Optional[Dict] = None):
+        if state is None:
+            state = {}
+        super(State, self).__setattr__("_state", state)
+
+    def __setattr__(self, key: Any, value: Any) -> None:
+        self._state[key] = value
+
+    def __getattr__(self, key: Any) -> Any:
+        try:
+            return self._state[key]
+        except KeyError:
+            raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{key}'")
+
+    def __len__(self):
+        return len(self._state)
+
+    def __delattr__(self, key: Any) -> None:
+        del self._state[key]
+
 
 @dataclass()
 class Event(object):
@@ -61,11 +90,11 @@ def _get_event_loop():
 
 
 def gen_random_str_id(length: int = 8) -> str:
-    return "".join(random.choice(_STR_LD) for i in range(length))
+    return "".join(random.choice(_STR_LD) for _ in range(length))
 
 
 def gen_random_time_id(length: int = 8, time_length: int = 10) -> str:
-    return str(int(time.time()))[-time_length:] + "".join(random.choice(_STR_LD) for i in range(length))
+    return str(int(time.time()))[-time_length:] + "".join(random.choice(_STR_LD) for _ in range(length))
 
 
 get_event_loop = _get_event_loop()
