@@ -1,26 +1,21 @@
 import asyncio
 import logging
 import ssl
+from typing import Callable, Coroutine, List, Optional, Union
 
 import msgpack
 
-from typing import Callable, Coroutine, List, Optional, Union
-
 from rap.common.conn import ServerConnection
 from rap.common.exceptions import RpcRunTimeError
-from rap.common.types import READER_TYPE, WRITER_TYPE, BASE_REQUEST_TYPE
+from rap.common.middleware import BaseMiddleware
+from rap.common.types import BASE_REQUEST_TYPE, READER_TYPE, WRITER_TYPE
 from rap.common.utlis import Constant, Event
 from rap.manager.func_manager import func_manager
-from rap.server.middleware.base import (
-    BaseConnMiddleware,
-    BaseMsgMiddleware,
-    BaseRequestMiddleware,
-    BaseResponseMiddleware,
-)
-from rap.common.middleware import BaseMiddleware
-from rap.server.requests import Request, RequestModel
-from rap.server.response import Response, ResponseModel
-
+from rap.server.middleware.base import BaseConnMiddleware, BaseMsgMiddleware
+from rap.server.model import RequestModel, ResponseModel
+from rap.server.processor.base import BaseProcessor
+from rap.server.requests import Request
+from rap.server.response import Response
 
 __all__ = ["Server"]
 
@@ -57,6 +52,7 @@ class Server(object):
 
         self._server: Optional[asyncio.AbstractServer] = None
         self._middleware_list: List[BaseMiddleware] = []
+        self._filter_list: List[BaseProcessor] = []
 
     def load_middleware(self, middleware_list: List[BaseMiddleware]):
         for middleware in middleware_list:
@@ -66,7 +62,12 @@ class Server(object):
             elif isinstance(middleware, BaseMiddleware):
                 self._middleware_list.append(middleware)
             else:
-                raise RuntimeError(f'{middleware} must instance of {BaseMiddleware}')
+                raise RuntimeError(f"{middleware} must instance of {BaseMiddleware}")
+
+    def load_filter(self, filter_list: List[BaseProcessor]):
+        for filter_ in filter_list:
+            if isinstance(filter_, BaseProcessor):
+                self._filter_list.append(filter_)
 
     @staticmethod
     def register(func: Optional[Callable], name: Optional[str] = None, group: str = "normal"):
@@ -106,26 +107,19 @@ class Server(object):
         await self._conn_handle(conn)
 
     async def _conn_handle(self, conn: ServerConnection):
-        response_handle: Response = Response(conn, self._timeout)
-        request_handle: Request = Request(conn, self._run_timeout)
+        response_handle: Response = Response(conn, self._timeout, filter_list=self._filter_list)
+        request_handle: Request = Request(conn, self._run_timeout, response_handle, filter_list=self._filter_list)
         for middleware in self._middleware_list:
-            if isinstance(middleware, BaseRequestMiddleware):
-                middleware.load_sub_middleware(request_handle.real_dispatch)
-                request_handle.real_dispatch = middleware
-            elif isinstance(middleware, BaseMsgMiddleware):
+            if isinstance(middleware, BaseMsgMiddleware):
                 middleware.load_sub_middleware(request_handle.msg_handle)
                 request_handle.msg_handle = middleware
-            elif isinstance(middleware, BaseResponseMiddleware):
-                middleware.load_sub_middleware(response_handle.response_handle)
-                request_handle.response_handle = middleware
 
         async def recv_msg_handle(_request_msg: Optional[BASE_REQUEST_TYPE]):
             if _request_msg is None:
                 await response_handle(ResponseModel(body=Event(Constant.EVENT_CLOSE_CONN, "request is empty")))
                 return
             try:
-                request_num, msg_id, header, body = _request_msg
-                request: RequestModel = RequestModel(request_num, msg_id, header, body)
+                request: RequestModel = RequestModel(*_request_msg)
                 request.header["_host"] = conn.peer
             except Exception as closer_e:
                 logging.error(f"{conn.peer} send bad msg:{_request_msg}, error:{closer_e}")
